@@ -10,7 +10,7 @@ from .proto.market_data_pb2 import (
     TransFlagEnum,
     TrdTypeEnum,
     DirectionEnum,
-    OrdTypeEnum,
+    OrdActionTypeEnum,
     TickStatusFlagEnum,
     ExerciseStyleEnum,
     HktTradeLimitEnum,
@@ -105,15 +105,15 @@ class Direction(IntEnum):
         """处理无效的枚举值"""
         return cls.UNKNOWN  # 返回默认值
 
-class OrdType(IntEnum):
+class OrdActionType(IntEnum):
     """订单类别"""
-    UNKNOWN = OrdTypeEnum.TORT_UNKNOWN        # 未知类型
-    MARKET = OrdTypeEnum.TORT_Market          # SZ市价 ('1'的ASCII码)
-    LIMIT = OrdTypeEnum.TORT_Limit            # SZ限价 ('2'的ASCII码)
-    MARKET_SELF = OrdTypeEnum.TORT_MarketSelf # SZ本方最优 ('U'的ASCII码)
-    ADD = OrdTypeEnum.TORT_Add                # SH增加委托订单 ('A'的ASCII码)
-    DELETE = OrdTypeEnum.TORT_Delete          # SH删除委托订单 ('D'的ASCII码)
-    STATUS = OrdTypeEnum.TORT_Status          # 产品状态订单 ('S'的ASCII码)
+    UNKNOWN = OrdActionTypeEnum.TORT_UNKNOWN        # 未知类型
+    MARKET = OrdActionTypeEnum.TORT_Market          # SZ市价 ('1'的ASCII码)
+    LIMIT = OrdActionTypeEnum.TORT_Limit            # SZ限价 ('2'的ASCII码)
+    MARKET_SELF = OrdActionTypeEnum.TORT_MarketSelf # SZ本方最优 ('U'的ASCII码)
+    ADD = OrdActionTypeEnum.TORT_Add                # SH增加委托订单 ('A'的ASCII码)
+    DELETE = OrdActionTypeEnum.TORT_Delete          # SH删除委托订单 ('D'的ASCII码)
+    STATUS = OrdActionTypeEnum.TORT_Status          # 产品状态订单 ('S'的ASCII码)
 
     def __str__(self):
         # 直接将整数值转换为字符
@@ -121,13 +121,13 @@ class OrdType(IntEnum):
         char_str = f"'{char_value}'" if char_value else ""
         
         return {
-            OrdType.UNKNOWN: f"未知({self.name}={char_str})",
-            OrdType.MARKET: f"市价委托({self.name}={char_str})",
-            OrdType.LIMIT: f"限价委托({self.name}={char_str})",
-            OrdType.MARKET_SELF: f"本方最优({self.name}={char_str})",
-            OrdType.ADD: f"增加订单({self.name}={char_str})",
-            OrdType.DELETE: f"删除订单({self.name}={char_str})",
-            OrdType.STATUS: f"产品状态订单({self.name}={char_str})"
+            OrdActionType.UNKNOWN: f"未知({self.name}={char_str})",
+            OrdActionType.MARKET: f"市价委托({self.name}={char_str})",
+            OrdActionType.LIMIT: f"限价委托({self.name}={char_str})",
+            OrdActionType.MARKET_SELF: f"本方最优({self.name}={char_str})",
+            OrdActionType.ADD: f"增加订单({self.name}={char_str})",
+            OrdActionType.DELETE: f"删除订单({self.name}={char_str})",
+            OrdActionType.STATUS: f"产品状态订单({self.name}={char_str})"
         }[self]
 
     @classmethod
