@@ -19,11 +19,11 @@ from .utils import get_allocation_granularity, time_to_milliseconds, get_total_c
 from .exceptions import NoDataException, DataFormatException, FileAccessException, ProtobufParseException
 
 from .proto.market_data_pb2 import (
+    Envelope,
     SecuDepthMarketData,
     TransactionEntrustData,
     TransactionTradeData
 )
-from .proto.global_pb2 import Envelope
 from .models import MarketDataResult
 
 ALLOCATION_GRANULARITY = get_allocation_granularity()
@@ -243,6 +243,8 @@ class MarketDataReader:
         self.data_reader = MappedFileReader(self.logger, data_file)
         self.last_index_size = 0    # 初始化为0，表示从头开始
         self.current_sequence = -1  # 初始序列号
+        self.read_count = 0         # 添加读取计数器
+        self.first_read = True      # 标记是否为第一次读取
 
     def get_count(self) -> int:
         """获取最新的文件大小"""
@@ -312,6 +314,13 @@ class MarketDataReader:
 
             # 更新当前序列号（如果需要）
             self.current_sequence = header.sequence_no
+            
+            # 更新读取计数
+            self.read_count += 1
+            
+            # 每读取1000条数据打印一次日志
+            if self.read_count % 1000 == 0:
+                self.logger.debug(f"已读取 {self.read_count} 条市场数据")
 
             return header, envelope
 
@@ -327,6 +336,12 @@ class MarketDataReader:
             if current_index_size == self.last_index_size:
                 return None  # 无新数据
             
+            # 如果是第一次读取，打印可用数据条数
+            if self.first_read:
+                total_entries = current_index_size // IndexEntry.size()
+                self.logger.debug(f"首次读取，共有 {total_entries} 条市场数据可用")
+                self.first_read = False
+            
             while self.last_index_size + IndexEntry.size() <= current_index_size and len(data := self.index_reader.read(IndexEntry.size())) == IndexEntry.size():
                 # 读取索引项
                 self.index_reader.seek(self.last_index_size)
@@ -338,7 +353,8 @@ class MarketDataReader:
                 index_entry = IndexEntry.from_bytes(index_data)
                 # 检查序列号，避免重复读取
                 if index_entry.sequence_no <= self.current_sequence:
-                    self.logger.debug(f"跳过旧的序列号: {index_entry.sequence_no}")
+                    if index_entry.sequence_no != 0:
+                        self.logger.debug(f"跳过旧的序列号: {index_entry.sequence_no}")
                     # 使用return而非continue避免死循环
                     return None  # 跳过旧数据
                 self.last_index_size += IndexEntry.size()
@@ -370,6 +386,13 @@ class MarketDataReader:
                     return None  # 解析失败，跳过
 
                 self.current_sequence = header.sequence_no
+                
+                # 更新读取计数
+                self.read_count += 1
+                
+                # 每读取1000条数据打印一次日志
+                if self.read_count % 1000 == 0:
+                    self.logger.debug(f"已读取 {self.read_count} 条市场数据")
 
                 return [header, market_data]
 
